%It executes MLMaOP for a number of runs equal to numIter
 function mainMLMaOP(numLayers,fileInput,fileClasses,numClasses)

%%%%%%%%%%%%%%%%%%%%%%
%numLayers: number of layers of the graph
%fileinput: list of edges of the graph specified as a triple (node source
%ID, node destination ID, number of layer)
%fileClasses: couples (node ID, number of community) representing the ground truth, if the true partitioning is known it is possible to compute the Normalized
%Mutual information
%numClasses: number of true communities

%The program generates two output files: fileClasses.ris containing average
%results obtained by running the method numIter times, and fileClasses.sol,
%containing the clustering computed by the method.
%All the compoutation is saved in the file results.mat containing, for each iteration of the algorithm, the following:
%NMIris: maximum NMI value of the Pareto front and the corresponding modularity value
%NMIConsensus: maximum NMI value and the corresponding modularity value of the solution chosen with the consensus method
%MODris: maximum modularity value of the Pareto front and the corresponding NMI value
%MODmeanLivelli: mean value of the maximum modularity of each layer



%set parameters for the multiobjective GA
mutationRate=0.2;
CrossoverFraction=0.8;
parallelExec='off'; %set 'on' if you want to use the parallel execution of MATLAB
maxGen=100;  %max number of generations
PopSize=200; %population size
numIter=5;  %number of iterations the algoritm is executed

if nargin  <2
    disp('not enough parameters')
    return;
else
    if nargin == 2
       numClasses=0;
       fileClasses=' '; 
       [NMIris NMIConsensus MODris MODmeanLivelli]=MultiGA(numLayers,fileinput,fileClasses,numClasses,mutationRate,CrossoverFraction,maxGen,PopSize,numIter,parallelExec);
    
    else
    if nargin ==4
       [NMIris NMIConsensus MODris MODmeanLivelli]=MultiGA(numLayers,fileInput,fileClasses,numClasses,mutationRate,CrossoverFraction,maxGen,PopSize,numIter,parallelExec); 

    else
        disp('wrong number of parameters')       
    end
    end
end
hold on
save('results.mat','NMIris','NMIConsensus','MODris','MODmeanLivelli');

 end

